==> haskell-tar-0.5.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.0.3
id: tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M
key: tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M
license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
exposed: True
indefinite: False
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
abi: 537fd462573572155fedd756721a4cd6
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tar-0.5.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/tar-0.5.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/tar-0.5.0.3
hs-libraries: HStar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M
depends:
    base-4.10.0.0 filepath-1.4.1.2 directory-1.3.0.2 array-0.5.2.0
    containers-0.5.10.2 deepseq-1.4.3.0 time-1.8.0.2
    bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             filepath-1.4.1.2=30ad74f2069d36b2d0af3972630d4ac4
             directory-1.3.0.2=f0be8e5bd351f97ab9c9e693d2eba4ad
             array-0.5.2.0=5abf025fb7bf60079ec1f42bab285152
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
             time-1.8.0.2=3f789f9c9fc88790a10579b55c2f0b4f
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-0.5.0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.0.3
id: tar-0.5.0.3-7uH7Usofl2BFmvax6EB94t
key: tar-0.5.0.3-7uH7Usofl2BFmvax6EB94t
license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
exposed: True
indefinite: False
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Check Codec.Archive.Tar.Entry
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
abi: 2464e73cf32d7a5f49b381c1dd961d93
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tar-0.5.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/tar-0.5.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tar-0.5.0.3
hs-libraries: HStar-0.5.0.3-7uH7Usofl2BFmvax6EB94t
depends:
    base-4.10.1.0 filepath-1.4.1.2 directory-1.3.0.2 array-0.5.2.0
    containers-0.5.10.2 deepseq-1.4.3.0 time-1.8.0.2
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
